//
// Ryan Cunningham
//
// To enable auto-follow breakpoints
// #include this file in the function _initialize_breakpoint
// in gdb's breakpoint.c file. This adds the necessary
// ui commands to gdb.
// Also follow the instructions in gdb_callback_breakpoint.c
//


// changes for cbreak
  add_com ("cbreak", class_breakpoint, cbreak_command,
	    concat ("Set a callback breakpoint for the current line.\n\
Argment may be a pattern followed by an argument number,\n\
See set-follow-callback for details.", NULL));

  add_com_alias ("cb", "cbreak", class_run, 1);
  
  add_com ("tcbreak", class_breakpoint, tcbreak_command,
	    concat ("Set a temporary callback breakpoint for the current line.\n\
Argment may be a pattern followed by an argument number,\n\
See set-follow-callback for details.", NULL));

  add_com_alias ("tcb", "tcbreak", class_run, 1);
  
  add_com ("follow-callback", class_breakpoint, follow_callback,
	    concat ("Set a callback breakpoint and continue execution.\n\
Argment may be a pattern followed by an argument number,\n\
See set-follow-callback for details.", NULL));

  add_com_alias ("follow", "follow_callback", class_run, 1);
  add_com_alias ("fol", "follow_callback", class_run, 1);
  
  add_com ("tfollow-callback", class_breakpoint, tfollow_callback,
	    concat ("Set a temporary callback breakpoint and continue execution.\n\
Argment may be a pattern followed by an argument number,\n\
See set-follow-callback for details.", NULL));

  add_com_alias ("tfollow", "tfollow_callback", class_run, 1);
  add_com_alias ("tfol", "tfollow_callback", class_run, 1);
  
  add_com ("set-follow-callback", class_breakpoint, set_follow_callback,
	    concat ("Set the follow callback pattern and argument number.\n\
Leave the argument blank to reset the pattern to default (default='*wrap(<cb>,<id><sep> 0').\n\
The pattern takes the form '*' for wildcard, '<cb>' for callback function\n\
token, '<id>' for a unique identifier expression that will match an argument\n\
in the callback function and <sep> for a function argument separator (i.e. ')' or ','). \n\
The pattern should have no spaces. The pattern must end\n\
with a character to match and a * may not be adjacent to a <> tag. Following the pattern\n\
is a space then a zero based number representing the argument number within\n\
the callback function that the id will match.", NULL));

  add_com ("cnext", class_breakpoint, callback_next,
	    concat ("If on a callback line, set a temporary callback breakpoint\n\
and continue. If not on a regular line, just step to the next line.\n", NULL));

  add_com_alias ("cn", "cnext", class_run, 1);

#ifdef INCLUDE_AUTO_CBREAK
// Only include the 'auto' commands if requested to at compile time.
// The 'auto' version is for C++ using wrap() from the libasync (part of SFS).
  add_com ("acbreak", class_breakpoint, acbreak_command,
	    concat ("Set a auto callback breakpoint for the current line.\n\
Argment may be a pattern,\n\
See set-auto-follow-callback for details.", NULL));

  add_com_alias ("ac", "acbreak", class_run, 1);
  
  add_com ("atcbreak", class_breakpoint, atcbreak_command,
	    concat ("Set a temporary auto callback breakpoint for the current line.\n\
Argment may be a pattern,\n\
See set-auto-follow-callback for details.", NULL));

  add_com_alias ("atc", "atcbreak", class_run, 1);
  
  add_com ("afollow-callback", class_breakpoint, afollow_callback,
	    concat ("Set a auto callback breakpoint and continue execution.\n\
Argment may be a pattern,\n\
See set-auto-follow-callback for details.", NULL));

  add_com_alias ("afollow", "afollow_callback", class_run, 1);
  add_com_alias ("af", "afollow_callback", class_run, 1);
  
  add_com ("atfollow-callback", class_breakpoint, atfollow_callback,
	    concat ("Set a temporary auto callback breakpoint and continue execution.\n\
Argment may be a pattern,\n\
See set-auto-follow-callback for details.", NULL));

  add_com_alias ("atfollow", "atfollow_callback", class_run, 1);
  add_com_alias ("atf", "atfollow_callback", class_run, 1);
  
  add_com ("set-auto-follow-callback", class_breakpoint, set_afollow_callback,
	    concat ("Set the *auto* follow callback pattern.\n\
Leave the argument blank to reset the pattern to default (default='*debug_wrap(<cb><sep>').\n\
The pattern takes the form '*' for wildcard, '<cb>' for callback function\n\
token, and <sep> for a function argument separator (i.e. ')' or ','). \n\
The pattern should have no spaces. The pattern must end\n\
with a character to match and a * may not be adjacent to a <> tag.", NULL));

  add_com_alias ("set-auto", "set_afollow_callback", class_run, 1);
  add_com_alias ("set-a", "set_afollow_callback", class_run, 1); 
  
  add_com ("set-auto-id-expressions", class_breakpoint, set_auto_id_exprs,
	    concat ("Set the auto follow callback next and current id expressions.\n\
Expressions should have no spaces. The first argument should be the next id expression.\n\
The second argument should be the current id expression.\n", NULL));

  add_com_alias ("set-auto-id", "set_auto_id_exprs", class_run, 1);
  
  add_com ("anext", class_breakpoint, auto_next,
	    concat ("If on a callback line, set the auto follow callback.\n\
and continue. If not on a regular line, just step to the next line.\n", NULL));

  add_com_alias ("an", "anext", class_run, 1);
#endif // INCLUDE_AUTO_CBREAK
// end cbreak changes
